@@ -200,6 +200,8 @@ def get_sourceColor(source=None):
         "Biomass burning": "#92d050",
         "Biomass_burning1": "#92d050",
         "Biomass_burning2": "#92d050",
+        "Sulphate-rich": "#ff2a2a",
+        "Sulphate_rich": "#ff2a2a",
         "Sulfate-rich": "#ff2a2a",
         "Sulfate_rich": "#ff2a2a",
         "Sulfate rich": "#ff2a2a",
@@ -230,6 +232,7 @@ def get_sourceColor(source=None):
         "Seasalt": "#00b0f0",
         "Sea-road salt": "#209ecc",
         "Sea/road salt": "#209ecc",
+        "Fresh sea salt": "#00b0f0",
         "Fresh seasalt": "#00b0f0",
         "Aged_salt": "#97bdff", #00b0f0",
         "Aged seasalt": "#97bdff", #00b0f0",
